#------------------------------------------------------------------------------------------------
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#------------------------------------------------------------------------------------------------
#  Name:	AddPts2Curve
#    By:	sdmitch
# Usage:	Add a vertex to an existing curve at a given distance from start.
#  Date:	Nov 2011
#------------------------------------------------------------------------------------------------

require 'Sketchup'

if !file_loaded?(File.basename(__FILE__))
	UI.menu("Plugins").add_item("AddPts2Curve") { AddPts2Curve.do_curve}
	file_loaded(File.basename(__FILE__))
end#if

module AddPts2Curve
	
	def self.do_curve
		mod = Sketchup.active_model
		ent = mod.active_entities
		sel = mod.selection
		if sel.empty? or !sel.first.curve then
			UI.messagebox "No Curve selected";return
		end
		ans=UI.inputbox(["Distance Increment:"],[nil],"Add Points to Curve")
		if !ans then return end
		dinc=ans[0].to_l; curve=sel.first.curve; clen = curve.length
		if dinc < clen then
			mod.start_operation "Add Points to Curve"
			pts=curve.vertices.collect{|v| v.position}
			dist=dinc; i = 1; npts=[];npts.push pts[0]
			while i < pts.length
				d = npts[-1].distance(pts[i])
				v = npts[-1].vector_to(pts[i])
				if d < dist then
					npts.push pts[i]
					dist -= d
					i += 1
				elsif d == dist
					npts.push pts[i]
					dist = dinc
					i += 1
				elsif d > dist
					p0=npts[-1].offset(v,dist)
					ent.add_cpoint(p0)
					npts.push p0
					dist = dinc
				end
			end
			curve = ent.add_curve(npts)
			sel.clear; sel.add curve
			mod.commit_operation
		else
			UI.messagebox("Distance entered is longer than the selected curve")
		end
	end
	
end#module
